# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: oauth_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13oauth_service.proto\"^\n\x1aGetProviderLoginURLRequest\x12\x14\n\x0c\x63\x61llback_url\x18\x01 \x01(\t\x12\x19\n\x0c\x61\x63\x63\x65ss_token\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0f\n\r_access_token\"?\n\x1bGetProviderLoginURLResponse\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x13\n\x0bstate_token\x18\x02 \x01(\t\"6\n\x11OAuthLoginRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x13\n\x0bstate_token\x18\x02 \x01(\t\"i\n\x12OAuthLoginResponse\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\x12\x12\n\nexpires_in\x18\x03 \x01(\r\x12\x12\n\ntoken_type\x18\x04 \x01(\t\"U\n\x1a\x41ttachAccountToUserRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x13\n\x0bstate_token\x18\x03 \x01(\t\"\x1d\n\x1b\x41ttachAccountToUserResponse\"4\n\x1c\x44\x65tachAccountFromUserRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\"\x1f\n\x1d\x44\x65tachAccountFromUserResponse2\xbb\x02\n\x0bGoogleOAuth\x12P\n\x13GetProviderLoginURL\x12\x1b.GetProviderLoginURLRequest\x1a\x1c.GetProviderLoginURLResponse\x12\x30\n\x05Login\x12\x12.OAuthLoginRequest\x1a\x13.OAuthLoginResponse\x12P\n\x13\x41ttachAccountToUser\x12\x1b.AttachAccountToUserRequest\x1a\x1c.AttachAccountToUserResponse\x12V\n\x15\x44\x65tachAccountFromUser\x12\x1d.DetachAccountFromUserRequest\x1a\x1e.DetachAccountFromUserResponse2\xbb\x02\n\x0bYandexOAuth\x12P\n\x13GetProviderLoginURL\x12\x1b.GetProviderLoginURLRequest\x1a\x1c.GetProviderLoginURLResponse\x12\x30\n\x05Login\x12\x12.OAuthLoginRequest\x1a\x13.OAuthLoginResponse\x12P\n\x13\x41ttachAccountToUser\x12\x1b.AttachAccountToUserRequest\x1a\x1c.AttachAccountToUserResponse\x12V\n\x15\x44\x65tachAccountFromUser\x12\x1d.DetachAccountFromUserRequest\x1a\x1e.DetachAccountFromUserResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'oauth_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GETPROVIDERLOGINURLREQUEST._serialized_start=23
  _GETPROVIDERLOGINURLREQUEST._serialized_end=117
  _GETPROVIDERLOGINURLRESPONSE._serialized_start=119
  _GETPROVIDERLOGINURLRESPONSE._serialized_end=182
  _OAUTHLOGINREQUEST._serialized_start=184
  _OAUTHLOGINREQUEST._serialized_end=238
  _OAUTHLOGINRESPONSE._serialized_start=240
  _OAUTHLOGINRESPONSE._serialized_end=345
  _ATTACHACCOUNTTOUSERREQUEST._serialized_start=347
  _ATTACHACCOUNTTOUSERREQUEST._serialized_end=432
  _ATTACHACCOUNTTOUSERRESPONSE._serialized_start=434
  _ATTACHACCOUNTTOUSERRESPONSE._serialized_end=463
  _DETACHACCOUNTFROMUSERREQUEST._serialized_start=465
  _DETACHACCOUNTFROMUSERREQUEST._serialized_end=517
  _DETACHACCOUNTFROMUSERRESPONSE._serialized_start=519
  _DETACHACCOUNTFROMUSERRESPONSE._serialized_end=550
  _GOOGLEOAUTH._serialized_start=553
  _GOOGLEOAUTH._serialized_end=868
  _YANDEXOAUTH._serialized_start=871
  _YANDEXOAUTH._serialized_end=1186
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: auth_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x61uth_service.proto\"/\n\x0cLoginRequest\x12\r\n\x05login\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"d\n\rLoginResponse\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\x12\x12\n\nexpires_in\x18\x03 \x01(\r\x12\x12\n\ntoken_type\x18\x04 \x01(\t\",\n\x13RefreshTokenRequest\x12\x15\n\rrefresh_token\x18\x01 \x01(\t\"k\n\x14RefreshTokenResponse\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\x12\x12\n\nexpires_in\x18\x03 \x01(\r\x12\x12\n\ntoken_type\x18\x04 \x01(\t\"%\n\rLogoutRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\"\x10\n\x0eLogoutResponse\"*\n\x12LogoutOtherRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\"\x15\n\x13LogoutOtherResponse\"C\n\x19UpdateUserPasswordRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"\x1c\n\x1aUpdateUserPasswordResponse\"=\n\x16UpdateUserEmailRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\"\x19\n\x17UpdateUserEmailResponse\")\n\x11\x43heckTokenRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\"G\n\x12\x43heckTokenResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x14\n\x07user_id\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\n\n\x08_user_id\"1\n\x18\x43heckServiceTokenRequest\x12\x15\n\rservice_token\x18\x01 \x01(\t\",\n\x19\x43heckServiceTokenResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x32\xe0\x03\n\x04\x41uth\x12&\n\x05Login\x12\r.LoginRequest\x1a\x0e.LoginResponse\x12;\n\x0cRefreshToken\x12\x14.RefreshTokenRequest\x1a\x15.RefreshTokenResponse\x12)\n\x06Logout\x12\x0e.LogoutRequest\x1a\x0f.LogoutResponse\x12\x38\n\x0bLogoutOther\x12\x13.LogoutOtherRequest\x1a\x14.LogoutOtherResponse\x12I\n\x0eUpdatePassword\x12\x1a.UpdateUserPasswordRequest\x1a\x1b.UpdateUserPasswordResponse\x12@\n\x0bUpdateEmail\x12\x17.UpdateUserEmailRequest\x1a\x18.UpdateUserEmailResponse\x12\x35\n\nCheckToken\x12\x12.CheckTokenRequest\x1a\x13.CheckTokenResponse\x12J\n\x11\x43heckServiceToken\x12\x19.CheckServiceTokenRequest\x1a\x1a.CheckServiceTokenResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'auth_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LOGINREQUEST._serialized_start=22
  _LOGINREQUEST._serialized_end=69
  _LOGINRESPONSE._serialized_start=71
  _LOGINRESPONSE._serialized_end=171
  _REFRESHTOKENREQUEST._serialized_start=173
  _REFRESHTOKENREQUEST._serialized_end=217
  _REFRESHTOKENRESPONSE._serialized_start=219
  _REFRESHTOKENRESPONSE._serialized_end=326
  _LOGOUTREQUEST._serialized_start=328
  _LOGOUTREQUEST._serialized_end=365
  _LOGOUTRESPONSE._serialized_start=367
  _LOGOUTRESPONSE._serialized_end=383
  _LOGOUTOTHERREQUEST._serialized_start=385
  _LOGOUTOTHERREQUEST._serialized_end=427
  _LOGOUTOTHERRESPONSE._serialized_start=429
  _LOGOUTOTHERRESPONSE._serialized_end=450
  _UPDATEUSERPASSWORDREQUEST._serialized_start=452
  _UPDATEUSERPASSWORDREQUEST._serialized_end=519
  _UPDATEUSERPASSWORDRESPONSE._serialized_start=521
  _UPDATEUSERPASSWORDRESPONSE._serialized_end=549
  _UPDATEUSEREMAILREQUEST._serialized_start=551
  _UPDATEUSEREMAILREQUEST._serialized_end=612
  _UPDATEUSEREMAILRESPONSE._serialized_start=614
  _UPDATEUSEREMAILRESPONSE._serialized_end=639
  _CHECKTOKENREQUEST._serialized_start=641
  _CHECKTOKENREQUEST._serialized_end=682
  _CHECKTOKENRESPONSE._serialized_start=684
  _CHECKTOKENRESPONSE._serialized_end=755
  _CHECKSERVICETOKENREQUEST._serialized_start=757
  _CHECKSERVICETOKENREQUEST._serialized_end=806
  _CHECKSERVICETOKENRESPONSE._serialized_start=808
  _CHECKSERVICETOKENRESPONSE._serialized_end=852
  _AUTH._serialized_start=855
  _AUTH._serialized_end=1335
# @@protoc_insertion_point(module_scope)



class Services:
    MOVIES_SEARCH_SERVICE: str = "movies_search_service"
    PROXY_AUTH_SERVICE: str = "proxy_auth_service"
    MOVIES_ADMIN_PANEL_SERVICE: str = "movies_admin_panel_service"
    MOVIES_UGC_SERVICE: str = "movies_ugc_service"
    MOVIES_NOTIFICATION_SERVICE: str = "movies_notification_service"



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: user_info_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17user_info_service.proto\"?\n\x1aGetNotificationInfoRequest\x12\x15\n\rservice_token\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\"a\n\x1bGetNotificationInfoResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x11\n\tis_active\x18\x03 \x01(\x08\x12\x14\n\x0cis_superuser\x18\x04 \x01(\x08\x32\\\n\x08UserInfo\x12P\n\x13GetNotificationInfo\x12\x1b.GetNotificationInfoRequest\x1a\x1c.GetNotificationInfoResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'user_info_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GETNOTIFICATIONINFOREQUEST._serialized_start=27
  _GETNOTIFICATIONINFOREQUEST._serialized_end=90
  _GETNOTIFICATIONINFORESPONSE._serialized_start=92
  _GETNOTIFICATIONINFORESPONSE._serialized_end=189
  _USERINFO._serialized_start=191
  _USERINFO._serialized_end=283
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class AttachAccountToUserRequest(_message.Message):
    __slots__ = ["access_token", "code", "state_token"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    STATE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    code: str
    state_token: str
    def __init__(self, access_token: _Optional[str] = ..., code: _Optional[str] = ..., state_token: _Optional[str] = ...) -> None: ...

class AttachAccountToUserResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DetachAccountFromUserRequest(_message.Message):
    __slots__ = ["access_token"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    def __init__(self, access_token: _Optional[str] = ...) -> None: ...

class DetachAccountFromUserResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetProviderLoginURLRequest(_message.Message):
    __slots__ = ["access_token", "callback_url"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    CALLBACK_URL_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    callback_url: str
    def __init__(self, callback_url: _Optional[str] = ..., access_token: _Optional[str] = ...) -> None: ...

class GetProviderLoginURLResponse(_message.Message):
    __slots__ = ["state_token", "url"]
    STATE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    state_token: str
    url: str
    def __init__(self, url: _Optional[str] = ..., state_token: _Optional[str] = ...) -> None: ...

class OAuthLoginRequest(_message.Message):
    __slots__ = ["code", "state_token"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    STATE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    code: str
    state_token: str
    def __init__(self, code: _Optional[str] = ..., state_token: _Optional[str] = ...) -> None: ...

class OAuthLoginResponse(_message.Message):
    __slots__ = ["access_token", "expires_in", "refresh_token", "token_type"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_IN_FIELD_NUMBER: _ClassVar[int]
    REFRESH_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOKEN_TYPE_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    expires_in: int
    refresh_token: str
    token_type: str
    def __init__(self, access_token: _Optional[str] = ..., refresh_token: _Optional[str] = ..., expires_in: _Optional[int] = ..., token_type: _Optional[str] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class CheckServiceTokenRequest(_message.Message):
    __slots__ = ["service_token"]
    SERVICE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    service_token: str
    def __init__(self, service_token: _Optional[str] = ...) -> None: ...

class CheckServiceTokenResponse(_message.Message):
    __slots__ = ["success"]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: bool = ...) -> None: ...

class CheckTokenRequest(_message.Message):
    __slots__ = ["access_token"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    def __init__(self, access_token: _Optional[str] = ...) -> None: ...

class CheckTokenResponse(_message.Message):
    __slots__ = ["success", "user_id"]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    success: bool
    user_id: str
    def __init__(self, success: bool = ..., user_id: _Optional[str] = ...) -> None: ...

class LoginRequest(_message.Message):
    __slots__ = ["login", "password"]
    LOGIN_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    login: str
    password: str
    def __init__(self, login: _Optional[str] = ..., password: _Optional[str] = ...) -> None: ...

class LoginResponse(_message.Message):
    __slots__ = ["access_token", "expires_in", "refresh_token", "token_type"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_IN_FIELD_NUMBER: _ClassVar[int]
    REFRESH_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOKEN_TYPE_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    expires_in: int
    refresh_token: str
    token_type: str
    def __init__(self, access_token: _Optional[str] = ..., refresh_token: _Optional[str] = ..., expires_in: _Optional[int] = ..., token_type: _Optional[str] = ...) -> None: ...

class LogoutOtherRequest(_message.Message):
    __slots__ = ["access_token"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    def __init__(self, access_token: _Optional[str] = ...) -> None: ...

class LogoutOtherResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class LogoutRequest(_message.Message):
    __slots__ = ["access_token"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    def __init__(self, access_token: _Optional[str] = ...) -> None: ...

class LogoutResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class RefreshTokenRequest(_message.Message):
    __slots__ = ["refresh_token"]
    REFRESH_TOKEN_FIELD_NUMBER: _ClassVar[int]
    refresh_token: str
    def __init__(self, refresh_token: _Optional[str] = ...) -> None: ...

class RefreshTokenResponse(_message.Message):
    __slots__ = ["access_token", "expires_in", "refresh_token", "token_type"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_IN_FIELD_NUMBER: _ClassVar[int]
    REFRESH_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOKEN_TYPE_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    expires_in: int
    refresh_token: str
    token_type: str
    def __init__(self, access_token: _Optional[str] = ..., refresh_token: _Optional[str] = ..., expires_in: _Optional[int] = ..., token_type: _Optional[str] = ...) -> None: ...

class UpdateUserEmailRequest(_message.Message):
    __slots__ = ["access_token", "email"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    email: str
    def __init__(self, access_token: _Optional[str] = ..., email: _Optional[str] = ...) -> None: ...

class UpdateUserEmailResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class UpdateUserPasswordRequest(_message.Message):
    __slots__ = ["access_token", "password"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    password: str
    def __init__(self, access_token: _Optional[str] = ..., password: _Optional[str] = ...) -> None: ...

class UpdateUserPasswordResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: role_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12role_service.proto\"2\n\x0eGetUserRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\"C\n\x1b\x41nyUserOAuthProviderAccount\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x12\n\naccount_id\x18\x02 \x01(\t\"\x8b\x01\n\x0fGetUserResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x11\n\tis_active\x18\x03 \x01(\x08\x12\x14\n\x0cis_superuser\x18\x04 \x01(\x08\x12\x34\n\x0eoauth_accounts\x18\x05 \x03(\x0b\x32\x1c.AnyUserOAuthProviderAccount\"R\n\x12GetUserListRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x13\n\x0bpage_number\x18\x02 \x01(\r\x12\x11\n\tpage_size\x18\x03 \x01(\r\"P\n\nUserInList\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x11\n\tis_active\x18\x03 \x01(\x08\x12\x14\n\x0cis_superuser\x18\x04 \x01(\x08\"\xa9\x01\n\x13GetUserListResponse\x12\x1c\n\x07results\x18\x01 \x03(\x0b\x32\x0b.UserInList\x12\x13\n\x0btotal_count\x18\x02 \x01(\r\x12\x13\n\x0btotal_pages\x18\x03 \x01(\r\x12\x16\n\tprev_page\x18\x04 \x01(\rH\x00\x88\x01\x01\x12\x16\n\tnext_page\x18\x05 \x01(\rH\x01\x88\x01\x01\x42\x0c\n\n_prev_pageB\x0c\n\n_next_page\";\n\x13\x43reatePolicyRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x0e\n\x06policy\x18\x02 \x01(\t\"\"\n\x14\x43reatePolicyResponse\x12\n\n\x02id\x18\x01 \x01(\t\"G\n\x13UpdatePolicyRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06policy\x18\x03 \x01(\t\"\x16\n\x14UpdatePolicyResponse\"7\n\x13\x44\x65letePolicyRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\"\x16\n\x14\x44\x65letePolicyResponse\"4\n\x10GetPolicyRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\"#\n\x11GetPolicyResponse\x12\x0e\n\x06policy\x18\x01 \x01(\t\"T\n\x14GetPolicyListRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x13\n\x0bpage_number\x18\x02 \x01(\r\x12\x11\n\tpage_size\x18\x03 \x01(\r\"\x9d\x01\n\x15GetPolicyListResponse\x12\x0e\n\x06policy\x18\x01 \x03(\t\x12\x13\n\x0btotal_count\x18\x02 \x01(\r\x12\x13\n\x0btotal_pages\x18\x03 \x01(\r\x12\x16\n\tprev_page\x18\x04 \x01(\rH\x00\x88\x01\x01\x12\x16\n\tnext_page\x18\x05 \x01(\rH\x01\x88\x01\x01\x42\x0c\n\n_prev_pageB\x0c\n\n_next_page\";\n\x12\x43heckAccessRequest\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x0f\n\x07inquiry\x18\x02 \x01(\t\"K\n\x13\x43heckAccessResponse\x12\x12\n\nhas_access\x18\x01 \x01(\x08\x12\x14\n\x07user_id\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\n\n\x08_user_id2\xd8\x03\n\tAdminRole\x12,\n\x07GetUser\x12\x0f.GetUserRequest\x1a\x10.GetUserResponse\x12\x38\n\x0bGetUserList\x12\x13.GetUserListRequest\x1a\x14.GetUserListResponse\x12;\n\x0c\x43reatePolicy\x12\x14.CreatePolicyRequest\x1a\x15.CreatePolicyResponse\x12;\n\x0cUpdatePolicy\x12\x14.UpdatePolicyRequest\x1a\x15.UpdatePolicyResponse\x12;\n\x0c\x44\x65letePolicy\x12\x14.DeletePolicyRequest\x1a\x15.DeletePolicyResponse\x12\x32\n\tGetPolicy\x12\x11.GetPolicyRequest\x1a\x12.GetPolicyResponse\x12>\n\rGetPolicyList\x12\x15.GetPolicyListRequest\x1a\x16.GetPolicyListResponse\x12\x38\n\x0b\x43heckAccess\x12\x13.CheckAccessRequest\x1a\x14.CheckAccessResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'role_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GETUSERREQUEST._serialized_start=22
  _GETUSERREQUEST._serialized_end=72
  _ANYUSEROAUTHPROVIDERACCOUNT._serialized_start=74
  _ANYUSEROAUTHPROVIDERACCOUNT._serialized_end=141
  _GETUSERRESPONSE._serialized_start=144
  _GETUSERRESPONSE._serialized_end=283
  _GETUSERLISTREQUEST._serialized_start=285
  _GETUSERLISTREQUEST._serialized_end=367
  _USERINLIST._serialized_start=369
  _USERINLIST._serialized_end=449
  _GETUSERLISTRESPONSE._serialized_start=452
  _GETUSERLISTRESPONSE._serialized_end=621
  _CREATEPOLICYREQUEST._serialized_start=623
  _CREATEPOLICYREQUEST._serialized_end=682
  _CREATEPOLICYRESPONSE._serialized_start=684
  _CREATEPOLICYRESPONSE._serialized_end=718
  _UPDATEPOLICYREQUEST._serialized_start=720
  _UPDATEPOLICYREQUEST._serialized_end=791
  _UPDATEPOLICYRESPONSE._serialized_start=793
  _UPDATEPOLICYRESPONSE._serialized_end=815
  _DELETEPOLICYREQUEST._serialized_start=817
  _DELETEPOLICYREQUEST._serialized_end=872
  _DELETEPOLICYRESPONSE._serialized_start=874
  _DELETEPOLICYRESPONSE._serialized_end=896
  _GETPOLICYREQUEST._serialized_start=898
  _GETPOLICYREQUEST._serialized_end=950
  _GETPOLICYRESPONSE._serialized_start=952
  _GETPOLICYRESPONSE._serialized_end=987
  _GETPOLICYLISTREQUEST._serialized_start=989
  _GETPOLICYLISTREQUEST._serialized_end=1073
  _GETPOLICYLISTRESPONSE._serialized_start=1076
  _GETPOLICYLISTRESPONSE._serialized_end=1233
  _CHECKACCESSREQUEST._serialized_start=1235
  _CHECKACCESSREQUEST._serialized_end=1294
  _CHECKACCESSRESPONSE._serialized_start=1296
  _CHECKACCESSRESPONSE._serialized_end=1371
  _ADMINROLE._serialized_start=1374
  _ADMINROLE._serialized_end=1846
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateUserRequest(_message.Message):
    __slots__ = ["email", "password"]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    email: str
    password: str
    def __init__(self, email: _Optional[str] = ..., password: _Optional[str] = ...) -> None: ...

class CreateUserResponse(_message.Message):
    __slots__ = ["email", "id"]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    email: str
    id: str
    def __init__(self, id: _Optional[str] = ..., email: _Optional[str] = ...) -> None: ...

class GetUserLoginHistoryRequest(_message.Message):
    __slots__ = ["access_token", "page_number", "page_size"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    PAGE_NUMBER_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    page_number: int
    page_size: int
    def __init__(self, access_token: _Optional[str] = ..., page_number: _Optional[int] = ..., page_size: _Optional[int] = ...) -> None: ...

class GetUserLoginHistoryResponse(_message.Message):
    __slots__ = ["next_page", "prev_page", "results", "total_count", "total_pages"]
    NEXT_PAGE_FIELD_NUMBER: _ClassVar[int]
    PREV_PAGE_FIELD_NUMBER: _ClassVar[int]
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_COUNT_FIELD_NUMBER: _ClassVar[int]
    TOTAL_PAGES_FIELD_NUMBER: _ClassVar[int]
    next_page: int
    prev_page: int
    results: _containers.RepeatedCompositeFieldContainer[UserLoginHistory]
    total_count: int
    total_pages: int
    def __init__(self, results: _Optional[_Iterable[_Union[UserLoginHistory, _Mapping]]] = ..., total_count: _Optional[int] = ..., total_pages: _Optional[int] = ..., prev_page: _Optional[int] = ..., next_page: _Optional[int] = ...) -> None: ...

class GetUserMeRequest(_message.Message):
    __slots__ = ["access_token"]
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    def __init__(self, access_token: _Optional[str] = ...) -> None: ...

class GetUserMeResponse(_message.Message):
    __slots__ = ["email", "oauth_accounts"]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    OAUTH_ACCOUNTS_FIELD_NUMBER: _ClassVar[int]
    email: str
    oauth_accounts: _containers.RepeatedCompositeFieldContainer[UserOAuthProviderAccount]
    def __init__(self, email: _Optional[str] = ..., oauth_accounts: _Optional[_Iterable[_Union[UserOAuthProviderAccount, _Mapping]]] = ...) -> None: ...

class UserLoginHistory(_message.Message):
    __slots__ = ["date", "device", "ip_address", "user_agent"]
    DATE_FIELD_NUMBER: _ClassVar[int]
    DEVICE_FIELD_NUMBER: _ClassVar[int]
    IP_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    USER_AGENT_FIELD_NUMBER: _ClassVar[int]
    date: str
    device: str
    ip_address: str
    user_agent: str
    def __init__(self, date: _Optional[str] = ..., ip_address: _Optional[str] = ..., user_agent: _Optional[str] = ..., device: _Optional[str] = ...) -> None: ...

class UserOAuthProviderAccount(_message.Message):
    __slots__ = ["account_id", "provider"]
    ACCOUNT_ID_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    account_id: str
    provider: str
    def __init__(self, provider: _Optional[str] = ..., account_id: _Optional[str] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class GetNotificationInfoRequest(_message.Message):
    __slots__ = ["id", "service_token"]
    ID_FIELD_NUMBER: _ClassVar[int]
    SERVICE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    id: str
    service_token: str
    def __init__(self, service_token: _Optional[str] = ..., id: _Optional[str] = ...) -> None: ...

class GetNotificationInfoResponse(_message.Message):
    __slots__ = ["email", "id", "is_active", "is_superuser"]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    IS_ACTIVE_FIELD_NUMBER: _ClassVar[int]
    IS_SUPERUSER_FIELD_NUMBER: _ClassVar[int]
    email: str
    id: str
    is_active: bool
    is_superuser: bool
    def __init__(self, id: _Optional[str] = ..., email: _Optional[str] = ..., is_active: bool = ..., is_superuser: bool = ...) -> None: ...
